@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.002001'; # VERSION
+our $VERSION = '1.002002'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -139,8 +139,8 @@ sub version_all_ok {
 
 # ABSTRACT: Check to see that version's in modules are sane
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -149,7 +149,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.002001
+version 1.002002
 
 =head1 SYNOPSIS
 
@@ -239,11 +239,6 @@ really doesn't make sense to use with just L<version_ok|/version_ok>
 this allows enabling of L<version>s C<is_strict> checks to ensure that your
 version is strict.
 
-=head1 LIMITATIONS
-
-Will not test Perl 5.12 C<package> version declarations because
-L<Module::Extract::VERSION> can't extract them yet.
-
 =head1 SEE ALSO
 
 The goal is to have the functionality of all of these.
@@ -258,13 +253,6 @@ The goal is to have the functionality of all of these.
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-Special thanks to particle C<<particle at cpan dot org>> for the original
-C<Test::Version> and letting me maintain it further. Thanks to Mike Doherty
-C<<doherty at cs dot dal dot ca>>, and Michael G. Schwern C<<schwern at pobox dot
-com>> for their patches.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
@@ -274,17 +262,34 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=item *
+
+Mike Doherty <doherty@cs.dal.ca>
+
+=item *
+
+particle <particle@cpan.org>
+
+=back
+
 =head1 AUTHOR
 
 Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Caleb Cushing.
+This software is Copyright (c) 2013 by Caleb Cushing.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
